# HelperLoader
#
# Adds Helper loading capability to the Shot Framework. Helpers are simply outsourcing libraries
# for use in Controllers only.
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/

require 'shot'

require_relative './library_load_exception'

class String
	# Converts a CamelCased string to a underscore_string
	def underscore
		self.gsub(/::/, '/').
				gsub(/([A-Z]+)([A-Z][a-z])/,'\1_\2').
				gsub(/([a-z\d])([A-Z])/,'\1_\2').
				tr("-", "_").
				downcase
	end
end

class HelperLoader < Loader
	def initialize(client)
		super(client)
		@type = 'helper'
	end

	def get(helper_name)
		if helper_exists? helper_name
			load "./application/helpers/#{helper_name.underscore}.rb"
		else
			raise HelperLoadException "Could not find helper #{helper_name}. Please verify it exists at application/helpers/#{helper_name.underscore}.rb"
		end
	end

	private

	def helper_exists?(helper)
		Dir.exists? 'application/helpers' and File.exists? "application/helpers/#{helper.underscore}.rb"
	end
end