# LibraryLoader
#
# Adds Helper loading capability to the Shot Framework. Helpers are simply outsourcing libraries
# for use in Controllers only.
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/

require 'shot'

require_relative './library_load_exception'

class String
	# Converts a CamelCased string to a underscore_string
	def underscore
		self.gsub(/::/, '/').
				gsub(/([A-Z]+)([A-Z][a-z])/,'\1_\2').
				gsub(/([a-z\d])([A-Z])/,'\1_\2').
				tr("-", "_").
				downcase
	end
end

class LibraryLoader < Loader
	def initialize(client)
		super(client)
		@type = 'library'
	end

	def get(library_name)
		if helper_exists helper
			load "./application/libraries/#{library_name.underscore}.rb"
		else
			raise LibraryLoadException "Could not find library #{library_name}. Please verify it exists at application/libraries/#{library_name.underscore}.rb"
		end
	end

	private

	def helper_exits(helper)
		Dir.exists? 'application/libraries' and File.exists? "application/libraries/#{helper.underscore}.rb"
	end
end